Stan Math Library: stan/math/prim/scal/meta/include_summand.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
include_summand.hpp File Reference
`#include <stan/math/prim/scal/meta/is_constant.hpp>`
`#include <stan/math/prim/scal/meta/scalar_type.hpp>`
`#include <boost/math/tools/promotion.hpp>`

Go to the source code of this file.

## Classes
struct | stan::math::include_summand< propto, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10 >
| Template metaprogram to calculate whether a summand needs to be included in a proportional (log) probability calculation. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.